import argparse

from .Add import add_task
from .Delete import delete_task_by_id
from .Mark import mark_task_by_id
from .Update import update_task_by_id
from .List import (
    list_all_tasks,
    list_done_tasks,
    list_todo_tasks,
    list_in_progress_tasks,
    list_not_done_tasks,
)

def main():
    parser = argparse.ArgumentParser(
        prog="tasks",
        description="tasks cli program helps you arrange your tasks and it is only for coders who likes terminal command line",
        epilog='Example: tasks add "Buy milk"',
        usage="tasks <command> [options]\n\nCommands:\n list\n delete <id>",
    )

    sub = parser.add_subparsers(dest="command", required=True)

    # tasks add "text"
    p_add = sub.add_parser("add")
    p_add.add_argument("text")

    # tasks update <id> "text"
    p_update = sub.add_parser("update")
    p_update.add_argument("id", type=int)
    p_update.add_argument("text")

    # tasks delete <id>
    p_delete = sub.add_parser("delete")
    p_delete.add_argument("id", type=int)

    # tasks list [filter]
    p_list = sub.add_parser("list")
    p_list.add_argument(
        "filter",
        nargs="?",
        choices=["all", "done", "todo", "in-progress", "notdone"],
        default="all",
    )

    # tasks mark-in-progress <id>
    p_mip = sub.add_parser("mark-in-progress")
    p_mip.add_argument("id", type=int)

    # tasks mark-done <id>
    p_done = sub.add_parser("mark-done")
    p_done.add_argument("id", type=int)

    args = parser.parse_args()

    if args.command == "add":
        add_task(args.text)

    elif args.command == "update":
        update_task_by_id(args.id, args.text)

    elif args.command == "delete":
        delete_task_by_id(args.id)

    elif args.command == "list":
        if args.filter in (None, "all"):
            list_all_tasks()
        elif args.filter == "done":
            list_done_tasks()
        elif args.filter == "todo":
            list_todo_tasks()
        elif args.filter == "in-progress":
            list_in_progress_tasks()
        elif args.filter == "notdone":
            list_not_done_tasks()

    elif args.command == "mark-in-progress":
        mark_task_by_id(args.id, "in-progress")

    elif args.command == "mark-done":
        mark_task_by_id(args.id, "done")


if __name__ == "__main__":
    main()



import json
import os
import sys
from .storage import load_tasks , FILE_NAME

def print_tasks(tasks):
    if len(tasks) == 0:
        print("No tasks found.")
        return

    for task in tasks:
        print(f"[{task['id']}] {task['description']}  --->  {task['status']}")


# List all tasks
def list_all_tasks():
    tasks = load_tasks()
    print_tasks(tasks)


# List all tasks that are done
def list_done_tasks():
    tasks = load_tasks()
    done = []
    for t in tasks:
        if t['status'] == 'done':
            done.append(t)
    print_tasks(done)

# List all tasks that are todo
def list_todo_tasks():
    tasks = load_tasks()
    todo = []
    for t in tasks:
        if t['status'] == 'todo':
            todo.append(t)
    print_tasks(todo)


# List all tasks that are not done (todo + in-progress)
def list_not_done_tasks():
    tasks = load_tasks()
    not_done = []
    for t in tasks:
        if t['status'] == 'todo' or t['status'] == 'in-progress':
            not_done.append(t)
    print_tasks(not_done)


# List all tasks that are in progress
def list_in_progress_tasks():
    tasks = load_tasks()
    in_progress = []
    for t in tasks:
        if t["status"] == "in-progress":
            in_progress.append(t)
    print_tasks(in_progress)






# update tasks by id
import json
from .storage import load_tasks , FILE_NAME

def update_task_by_id(tasks_id , new_note):
    tasks = load_tasks()
    for t in tasks:
        if t.get('id') == tasks_id:
            t['description'] = new_note

    with open(FILE_NAME ,'w') as f:
        json.dump(tasks , f , indent=4)
    
    print(f"Updated id={tasks_id}")







import json
from .storage import load_tasks , FILE_NAME


def delete_task_by_id(task_id):

    tasks = load_tasks()

    new_tasks = []
    for t in tasks:
        if t.get("id") != task_id:
            new_tasks.append(t)

    if len(new_tasks) == len(tasks):
        print(f"Task not found: id={task_id}")
        return
    
    with open(FILE_NAME , "w") as f:
        json.dump(new_tasks , f , indent=4)

    print(f"Deleted id={task_id}")




import json
from .storage import load_tasks , FILE_NAME

# mark taks by id
#done or in-progres

def mark_task_by_id(task_id , status):
    tasks = load_tasks()
    for t in tasks:
        if t.get('id') == task_id:
            t['status'] = status
    with open(FILE_NAME , 'w') as f:
        json.dump(tasks , f , indent=4)
    print(f"Updated task id={task_id}")